@@ -84,9 +84,7 @@ class EncryptingSenderKey(models.Model):
     chainId = models.CharField(max_length=10)
     step = models.IntegerField(default=0)
     user = models.ForeignKey(User, on_delete=models.CASCADE, related_name='encryptingSenderKeys')
-    chainKey = models.CharField(max_length=44)
-    public = models.CharField(max_length=44)
-    cipher = models.CharField(max_length=500)
+    key = models.CharField(max_length=500)
 
     class Meta:
         constraints = [models.UniqueConstraint(fields=['partyId', 'chainId', 'user'], name='unique_esk')]
